==> com.careboo.unity-algorand-sdk-2.1.0-pre.10.tgz: package/Tests/Runtime/CareBoo.AlgoSdk.IntegrationTests/AlgoApiClientTestFixture.cs <==
using System.Collections;
using System.Text;
using AlgoSdk;
using Cysharp.Threading.Tasks;
using NUnit.Framework;
using Unity.Collections;
using UnityEngine;
using UnityEngine.TestTools;

[System.Flags]
public enum AlgoServices : byte
{
    None = 0,
    Algod = 1,
    Kmd = 2,
    Indexer = 4
}

[TestFixture]
public abstract class AlgoApiClientTestFixture
{
    [OneTimeSetUp]
    public void OneTimeSetUp()
    {
        CheckServices();
    }

    protected static void AssertOkay(ErrorResponse error)
    {
        Assert.IsFalse(error.IsError, error.Message);
    }

    protected static async UniTask<PendingTransaction> WaitForTransaction(TransactionId txid)
    {
        async UniTask<bool> WaitMs(int ms)
        {
            await UniTask.Delay(ms);
            return true;
        }

        PendingTransaction pending = default;
        ErrorResponse error = default;
        do
        {
            (error, pending) = await AlgoApiClientSettings.Algod.GetPendingTransaction(txid);
            AssertOkay(error);
        }
        while (pending.ConfirmedRound == 0 && await WaitMs(1000));
        return pending;
    }

    virtual protected AlgoServices RequiresServices { get; }

    [UnitySetUp]
    public IEnumerator SetUpTest() => UniTask.ToCoroutine(SetUpAsync);

    [UnityTearDown]
    public IEnumerator TearDownTest() => UniTask.ToCoroutine(TearDownAsync);

    protected abstract UniTask SetUpAsync();

    protected abstract UniTask TearDownAsync();

    protected void CheckServices()
    {
        if (RequiresServices.HasFlag(AlgoServices.Algod))
            CheckAlgodService();
        if (RequiresServices.HasFlag(AlgoServices.Indexer))
            CheckIndexerService();
        if (RequiresServices.HasFlag(AlgoServices.Kmd))
            CheckKmdService();
    }

    static void CheckAlgodService()
    {
        if (string.IsNullOrWhiteSpace(AlgoApiClientSettings.Algod.Address))
            Assert.Ignore("Ignoring test because Algod Service has no Address.");
    }

    static void CheckIndexerService()
    {
        if (string.IsNullOrWhiteSpace(AlgoApiClientSettings.Indexer.Address))
            Assert.Ignore("Ignoring test because Indexer Service has no Address.");
    }

    static void CheckKmdService()
    {
        if (string.IsNullOrWhiteSpace(AlgoApiClientSettings.Kmd.Address))
            Assert.Ignore("Ignoring test because Kmd Service has no Address.");
    }
}

==> com.careboo.unity-algorand-sdk-3.0.0-pre.9.tgz: package/Tests/Runtime/CareBoo.AlgoSdk.IntegrationTests/AlgoApiClientTestFixture.cs <==
using System.Collections;
using System.Text;
using AlgoSdk;
using AlgoSdk.Algod;
using Cysharp.Threading.Tasks;
using NUnit.Framework;
using Unity.Collections;
using UnityEngine;
using UnityEngine.TestTools;

[System.Flags]
public enum AlgoServices : byte
{
    None = 0,
    Algod = 1,
    Kmd = 2,
    Indexer = 4
}

[TestFixture]
public abstract class AlgoApiClientTestFixture
{
    [OneTimeSetUp]
    public void OneTimeSetUp()
    {
        CheckServices();
    }

    protected static void AssertOkay(ErrorResponse error)
    {
        Assert.IsFalse(error.IsError, error.Message);
    }

    protected static async UniTask<PendingTransactionResponse> WaitForTransaction(TransactionId txid)
    {
        async UniTask<bool> WaitMs(int ms)
        {
            await UniTask.Delay(ms);
            return true;
        }

        PendingTransactionResponse pending = default;
        ErrorResponse error = default;
        do
        {
            (error, pending) = await AlgoApiClientSettings.Algod.PendingTransactionInformation(txid.ToString());
            AssertOkay(error);
        }
        while (pending.ConfirmedRound == 0 && await WaitMs(1000));
        return pending;
    }

    virtual protected AlgoServices RequiresServices { get; }

    [UnitySetUp]
    public IEnumerator SetUpTest() => UniTask.ToCoroutine(SetUpAsync);

    [UnityTearDown]
    public IEnumerator TearDownTest() => UniTask.ToCoroutine(TearDownAsync);

    protected abstract UniTask SetUpAsync();

    protected abstract UniTask TearDownAsync();

    protected void CheckServices()
    {
        if (RequiresServices.HasFlag(AlgoServices.Algod))
            CheckAlgodService();
        if (RequiresServices.HasFlag(AlgoServices.Indexer))
            CheckIndexerService();
        if (RequiresServices.HasFlag(AlgoServices.Kmd))
            CheckKmdService();
    }

    static void CheckAlgodService()
    {
        if (string.IsNullOrWhiteSpace(AlgoApiClientSettings.Algod.Address))
            Assert.Ignore("Ignoring test because Algod Service has no Address.");
    }

    static void CheckIndexerService()
    {
        if (string.IsNullOrWhiteSpace(AlgoApiClientSettings.Indexer.Address))
            Assert.Ignore("Ignoring test because Indexer Service has no Address.");
    }

    static void CheckKmdService()
    {
        if (string.IsNullOrWhiteSpace(AlgoApiClientSettings.Kmd.Address))
            Assert.Ignore("Ignoring test because Kmd Service has no Address.");
    }
}
